//---------------------------------------------------------------------------
#include <vcl\vcl.h>
#pragma hdrstop

#include "mainform.h"
//---------------------------------------------------------------------------
#pragma resource "*.dfm"
TForm1 *Form1;
//---------------------------------------------------------------------------
__fastcall TForm1::TForm1(TComponent* Owner)
	: TForm(Owner)
{
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button1Click(TObject *Sender)
{
		   webster->setKey(Edit1->Text.c_str());
           Memo1->Text = webster->operator char*();

}
//---------------------------------------------------------------------
void __fastcall TForm1::FormCreate(TObject *Sender)
{
	webster = new RawText("../../../modules/texts/rawtext/orthjbc/", "Webster", "Webster Text");
}
//---------------------------------------------------------------------
void __fastcall TForm1::FormDestroy(TObject *Sender)
{
	delete webster;
}
//---------------------------------------------------------------------